import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';

@Component({
  selector: 'app-input',
  templateUrl: './input.component.html',
  styleUrls: ['./input.component.scss'],
})
export class InputComponent implements OnInit {
  /** HTML id associated with for */
  @Input() id: string;

  @Input() type: 'text' | 'password' | 'time' = 'text';

  @Input() disabled = false;

  /** If set to 'on', enables autocomplete of the input DOM */
  @Input() autocomplete: 'on' | 'off' = 'off';

  /** Label for the input */
  @Input() label?: string;

  /** Affect the height of the input */
  @Input() size?: 'small' | 'large';

  /** If true, removes the max-width of the component to take 100% width */
  @Input() wide?: boolean;

  /** Additional label description */
  @Input() description?: string;

  /** What additional data should be displayed ? */
  @Input() status?: 'error' | 'success' | 'info' | 'warning';

  /** Additional text to display */
  @Input() statusText?: string;

  /** Text for placeholder */
  @Input() placeholder?: string = '';

  @Input() value: string;

  /** Triggers when input changes */
  @Output() valueChange = new EventEmitter<string>();

  @Output() finishedEditing = new EventEmitter<string>();

  includeShowHide = false;

  ngOnInit(): void {
    if (this.type === 'password') this.includeShowHide = true;
  }

  public get classes(): string {
    return [this.size, this.status, this.wide ? 'wide' : ''].join(' ');
  }

  public onChange(): void {
    this.valueChange.emit(this.value);
  }

  public onFinishedEditing(): void {
    this.finishedEditing.emit(this.value);
  }

  public toggleShowPassword(): void {
    this.type = this.type === 'password' ? 'text' : 'password';
  }

  getStatusText(): string {
    if (this.statusText) return this.statusText;

    switch (this.status) {
      case 'success':
        return `${this.label} valide`;
      case 'error':
        return `${this.label} invalide`;
      default:
        break;
    }
  }
}
